<?php
namespace skeeks\modules\cms\reviews\models;

use Yii;
use skeeks\cms\base\db\ActiveRecord;
use skeeks\cms\models\behaviors\HasDescriptionsBehavior;
use skeeks\cms\models\behaviors\HasFiles;
use skeeks\cms\models\behaviors\HasStatus;
use skeeks\cms\models\behaviors\Implode;
use skeeks\cms\models\Core;
use skeeks\cms\models\User;
use yii\helpers\ArrayHelper;

/**
 * This is the model class for table "reviews".
 *
 * @property integer $id
 * @property integer $created_by
 * @property integer $updated_by
 * @property integer $created_at
 * @property integer $updated_at
 * @property string $name
 * @property string $phone
 * @property string $email
 * @property string $text
 * @property string $url
 * @property integer $status
 *
 * @property CmsUser $createdBy
 * @property CmsUser $updatedBy
 */
class Reviews extends Core
{
    //use \skeeks\cms\models\behaviors\traits\HasFiles;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%reviews}}';
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {

        return ArrayHelper::merge(parent::behaviors(), [
            HasStatus::className() =>
            [
                'class' => HasStatus::className()
            ],
        ]);

    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return array_merge(parent::rules(), [
            [['created_by', 'updated_by', 'created_at', 'updated_at', 'status'], 'integer'],
            [['text'], 'required'],
            [['text'], 'string'],
            [['status'], 'default', 'value' => 20],
            [['name', 'phone', 'email', 'url'], 'string', 'max' => 255],
            [['email'], 'email'],
        ]);
    }

    public function scenarios()
    {
        $scenarios = parent::scenarios();

        $scenarios['create'] = $scenarios[self::SCENARIO_DEFAULT];
        $scenarios['update'] = $scenarios[self::SCENARIO_DEFAULT];

        return $scenarios;
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return  array_merge(parent::attributeLabels(), [
            'id' => 'ID',//\Yii::t('app', 'ID'),
            'name' => 'Имя',//\Yii::t('app', 'Name'),
            'phone' => 'Телефон',//\Yii::t('app', 'Phone'),
            'email' => 'E-mail',//\Yii::t('app', 'Email'),
            'text' => 'Текст',//\Yii::t('app', 'Text'),
            'url' => 'Url',//\Yii::t('app', 'Url'),
            //'user_id' => \Yii::t('app', 'User ID'),
            'status' => 'Статус',//\Yii::t('app', 'Status'),
        ]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    /*
    public function getUser()
    {
        return $this->hasOne(CmsUser::className(), ['id' => 'user_id']);
    }
    */

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCreatedBy()
    {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

    /**
     * @return User
     */
    public function fetchCreatedBy()
    {
        return $this->getCreatedBy()->one();
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getUpdatedBy()
    {
        return $this->hasOne(User::className(), ['id' => 'updated_by']);
    }

    /**
     * @return User
     */
    public function fetchUpdatedBy()
    {
        return $this->getUpdatedBy()->one();
    }
}